.. Bedrock Server Manager Core documentation index file

Core Documentation
==================

.. warning::
   The modules documented below are the internal engine of the Bedrock Server Manager. They are **not** part of the public API, are subject to change without notice, and **must not** be used directly by plugins. Functionality may be changed at any time.

This documentation is provided mostly for contributors working on the core application, or curious into its underlying functions not listed else where.

.. toctree::
   :maxdepth: 2
   :caption: BSM Exceptions

   error

.. toctree::
   :maxdepth: 2
   :caption: System Base

   system_base

.. toctree::
   :maxdepth: 2
   :caption: System Process

   system_process

.. toctree::
   :maxdepth: 2
   :caption: Utils

   utils

.. toctree::
   :maxdepth: 2
   :caption: Miscellaneous

   misc

Platform Dependent Core Documentation
-------------------------------------

.. toctree::
   :maxdepth: 2
   :caption: System Linux

   system_linux

.. toctree::
   :maxdepth: 2
   :caption: System Windows

   system_windows
